@@ -1,4 +1,4 @@
-# Copyright (c) 2023-2024 Arista Networks, Inc.
+# Copyright (c) 2023-2025 Arista Networks, Inc.
 # Use of this source code is governed by the Apache License 2.0
 # that can be found in the LICENSE file.
 """test anta.models.py."""
@@ -515,7 +515,7 @@ ANTATEST_DATA: list[dict[str, Any]] = [
     },
 ]
 
-BLACKLIST_COMMANDS_PARAMS = ["reload", "reload --force", "write", "wr mem"]
+BLACKLIST_COMMANDS_PARAMS = ["reload", "reload now", "reload --force", "write", "wr mem", "write memory", "conf t", "configure terminal", "configure session"]
 
 
 class TestAntaTest:
